# Tasting

A code-driven QA reporting library for Python. Automatically generate reports for QA to work from based on simple decorators.

NOTE: currently does nothing, in process of being implemented.
